1.1.4. What’s next? — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Tutorials »
- 1. Building a simple blog with CubicWeb »

# 1.1.4. What’s next?

In this tutorial, we have seen have you can, right after the installation of CubicWeb, build a web application in a few minutes by defining a data model as assembling cubes. You get a working application that you can then customize there and there while keeping something that works. This is important in agile development practices, you can right from the start of the project show things to customer and so take the right decision early in the process.

The next steps will be to discover hooks, security, data sources, digging deeper into view writing and interface customisation... Yet a lot of fun stuff to discover! You will find more tutorials and howtos in the blog published on the CubicWeb.org website.

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Tutorials »
- 1. Building a simple blog with CubicWeb »